@@ -14,16 +14,13 @@
 # limitations under the License.
 """Command group for Network Security Security Profiles."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 from googlecloudsdk.calliope import base
 
 
 @base.ReleaseTracks(
     base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA
 )
+@base.DefaultUniverseOnly
 class SecurityProfiles(base.Group):
   """Manage Network Security - Security Profiles.
 
